@@ -7,7 +7,7 @@ use 5.028;
 use feature 'say';
 use Data::Dumper;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 =head1 NAME
 
@@ -55,6 +55,11 @@ sub new
 
 1;
 
+=head1 BUGS
+
+For any feature requests or bug reports please visit:
+* Github L<https://github.com/PaulGWebster/p5-App-aep>
+
 =head1 AUTHOR
 
 Paul G Webster <daemon@cpan.org>
